/* Canvas.h
 *
 * Copyright 1999, Paul Kienzle (pkienzle@cs.indiana.edu)
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * * Initial revision
 */

#ifndef __CANVAS_H__
#define __CANVAS_H__


#include <gdk/gdk.h>
#include <gtk/gtkdrawingarea.h>
#include <gdk_imlib.h>


typedef struct _CanvasCursor {
  GdkImlibImage *image;
  GdkPixmap *backing_store;
  gint hot_x, hot_y;
  gint x, y;
  gint width, height;
  gboolean on_canvas;
  gint old_drawn, old_top, old_left, old_width, old_height;
} CanvasCursor;

typedef struct _Canvas {
  GtkWidget *widget;
  GtkDrawingArea *screen;
  GdkPixmap *canvas;
  gint width, height;
  gdouble scale;
  GdkImlibImage *background;
  GList *cursor_stack;
  gint cursor_stack_size;
} Canvas;


void cursor_push();
void cursor_pop();
void cursor_clear();
void cursor_draw(gboolean on_canvas, gint x, gint y);
void cursor_set(GdkImlibImage *image, gint hot_x, gint hot_y);
void cursor_off();
void cursor_on();
GdkImlibImage* canvas_image(void);
void canvas_clear();
GtkWidget *canvas_new(GdkImlibImage *background_image);

extern CanvasCursor cursor;
extern Canvas canvas;

#endif /* __CANVAS_H__ */







