/* Stickers.h
 *
 * Copyright 1999, Paul Kienzle (pkienzle@cs.indiana.edu)
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * * Initial revision
 */

/* portability problems solved by configure */
#include "config.h"

#if HAVE_DIRENT_H
# include <dirent.h>
# define NAMLEN(d) strlen((d)->d_name)
#else
# if HAVE_SYS_NDIR_H
#  include <sys/ndir.h>
# endif
# if HAVE_SYS_DIR_H
#  include <sys/dir.h>
# endif
# if HAVE_NDIR_H
#  incLude <ndir.h>
# endif
# if !defined (dirent)
#   define dirent direct
# endif /* !dirent */
# define NAMLEN(d) (d)->d_namlen
#endif

#if STDC_HEADERS
# include <string.h>
#else
# ifndef HAVE_STRCHR
#  define strchr index
#  define strrchr rindex
# endif
char *strchr (), *strrchr ();
# ifndef HAVE_MEMCPY
#  define memcpy(d, s, n) bcopy ((s), (d), (n))
#  define memmove(d, s, n) bcopy ((s), (d), (n))
# endif
#endif

#if TIME_WITH_SYS_TIME
# include <sys/time.h>
# include <time.h>
#else
# if HAVE_SYS_TIME_H
#  include <sys/time.h>
# else
#  include <time.h>
# endif
#endif

#if HAVE_UNISTD_H
# include <sys/types.h>
# include <unistd.h>
#endif

/* Internationalization (or not) */
#if 1
#include <libintl.h>
#define _(String) gettext(String)
#else
#define _(String) (String)
#define textdomain(Domain)
#define bindtextdomain(Package, Directory)
#endif

/* Start of the real header */
#include <stdio.h>
#include <gtk/gtk.h>
#include <gdk_imlib.h>


#if VERBOSE
#define TRACE ONTRACE
#else
#define TRACE NOTRACE
#endif

#define NOTRACE(x, args...) do { } while(0)
#define ONTRACE(format, args...) \
  fprintf(stderr, format  "\t##" __FUNCTION__ "(" __FILE__ ":%d)\n" \
	  , ## args , __LINE__)



typedef struct _STICKER {
  /* GdkImlibImage: rgb_width,rgb_height,rgb_data,alpha_data,filename */
  GdkImlibImage *image;  /* Sticker image read from file */
  gdouble base_scale;   /* inherent scale factor for the sticker */

  /* For save/load/redraw need the following */
  gdouble scale;        /* scale factor */
  gint rotate;          /* angle of rotation */
  gboolean flip;        /* True if using mirror image */
  gint hue, saturation, brightness;   /* HSV colour adjustment */
  gint alpha;           /* Opacity adjustment */
  gdouble rel_x, rel_y; /* relative position on the scene */

  /* For undo, need the following */
  gint x, y;            /* position */
  gint width, height;   /* size */
  GdkPixmap *backing_store; /* What's behind the sticker on the scene */
} Sticker;

extern Sticker *sticker;

typedef struct {
  gint button_size, scene_size;
  gint max_saved, max_history;
  gboolean paint; /* Paint/stamp state */
  gboolean confine, use_big_cursor, use_tiny_cursor; /* Pointer control */
  gboolean maximize; /* Start screen maximized */
  gboolean config, print; /* Available buttons */
  gchar *sticker_dir, *icon_dir, *work_dir;
  gchar *printfile, *printcmd, *signature, *sigfont;
  gint initial_delay;
  gint delay;

  GdkCursor *big_cursor, *tiny_cursor;
} Config;
extern Config config;


int size2pixel(int);
GtkWidget* button_new_with_image (gchar *image, gint size, gchar *label);
GtkWidget *
add_control(GtkWidget *control_box, char *ic, void (*callback)(), gchar *tip);

GdkImlibImage *sticker_render(Sticker *s);
void sticker_set_cursor(void);
void sticker_scale(gint c);
void sticker_rotate(gint c);
void sticker_hue(gint c);
void sticker_saturation(gint c);
void sticker_brightness(gint c);
void sticker_fade(gint c);
void sticker_vertical(gint control);
void sticker_horizontal(gint control);
void sticker_move(gint x, gint y);
void sticker_next(gint control);
void sticker_set(Sticker *s);

void sticker_restore(void);
void sticker_flip(void);

void sticker_paste(Sticker *s);
gboolean sticker_match(Sticker *a, Sticker *b);
Sticker *sticker_new(GdkImlibImage *image);
Sticker* sticker_load(FILE *file, gchar **imagename);
void sticker_save(Sticker *s, FILE *file);

void scene_redraw(void);
void scene_push(void);
void scene_pop(void);
void scene_clear(void);
void scene_grab(void);
void scene_save(void);
void scene_print(void);
gboolean scene_load(gchar *filename);
void scene_exit(GtkWidget *widget);
void scene_next_sticker(gint control);
void scene_new(void);
Sticker *scene_sticker_new_or_existing(gchar *name);

void select_scene(void);

void config_tip(GtkWidget *, gchar *);
gchar *config_signature();
void config_edit(void);
void config_load(gchar *filename);
void config_save(void);

void set_pointer (GtkWidget *);
void set_pointer_wait (GtkWidget *);
void map_window (GtkWidget *, GdkEvent *);
void enter_window (GtkWidget *, GdkEventCrossing *);
void leave_window (GtkWidget *, GdkEventCrossing *);
